3 ms·
It's been pretty fast since oxsfs was replaced with gRPR-fuse. Was in the beta builds for quite some time and now is switched on by default in 3.x. Idle CPU has
by JofArnold 6y ago
It's been pretty fast since oxsfs was replaced with gRPR-fuse. Was in the beta builds for quite some time and now is switched on by default in 3.x. Idle CPU has been cut from about 100% down to about 20% also.